* Code
  :PROPERTIES:
  :CREATED:   [2021-05-31 lun 11:27]
  :END:

Dash package is required. And, of course, Elfeed.

#+begin_src emacs-lisp
(require 'dash)
(require 'elfeed)
#+end_src

Two variables: entry title and entry contents.

#+begin_src emacs-lisp
  (defvar my-org/entry-title nil) ;; title
  (defvar my-org/entry-contents nil) ;; contents
#+end_src

A quick replace.

#+begin_src emacs-lisp
(defun my-replace (prev post)
  (save-excursion
    (goto-char (point-min))
    (while (re-search-forward prev nil t)
      (replace-match post t nil))))
#+end_src

Interleave titles with their contents.

#+begin_src emacs-lisp
  (defun my-org/interleave-entries-elfeed ()
    "interleave titles with contents"
    (setq lines-b (when (region-active-p)
		     (narrow-to-region (region-beginning) (region-end))
		     (split-string (buffer-string) "\n" nil)))
    (setq lines-c (-interleave lines-b my-org/entry-contents))
    (delete-region (region-beginning) (region-end))
    (deactivate-mark)
    (insert
     (mapconcat 'identity lines-c "\n")))
#+end_src

Store raw contens in a list.

#+begin_src emacs-lisp
(defun my-org/store-contents-elfeed ()
  "store contents in a list"
  (setq my-org/entry-contents nil)
  (save-excursion
    (goto-char (point-min))
    (save-window-excursion
      (while
	  (re-search-forward "\\(^[[:digit:]]+-\\)" nil t)
	(call-interactively 'elfeed-search-show-entry)
	(add-to-list 'my-org/entry-contents (buffer-string)
		     (switch-to-buffer "*elfeed-search*"))))))
#+end_src

Prepare all entries as an Org tree.

#+begin_src emacs-lisp
  (defun my-org/prepare-entries-elfeed ()
"prepare all entries in an Org tree"
    (interactive)
    (let* ((element (org-element-at-point))
	   (prop (org-element-property :ELFEED element))
	   (level (org-element-property :level element)))
      (save-restriction
	(org-narrow-to-subtree)
	(when
	    (re-search-forward "\\*+\s+Entries" nil t)
	  (save-restriction
	    (org-narrow-to-subtree)
	    (delete-region (point-min) (point-max)))))
      (save-restriction
	(org-narrow-to-subtree)
	(goto-char (point-max))
	(save-window-excursion
	  (call-interactively 'elfeed)
	  (elfeed-search-set-filter prop)
	  (setq my-org/entry-title (replace-regexp-in-string "\\([[:graph:]]+\\)\s\s+.+$" "\\1" (buffer-string)))
	  (my-org/store-contents-elfeed)
	  (kill-buffer))
	(let*
	    ((entries (with-temp-buffer
			 (insert my-org/entry-title)
			 ;; a temporal substitution
			 (my-replace "\\(^[[:digit:]]+-\\)" "¡>¡\\1")
			 (mark-whole-buffer)
			 (my-org/interleave-entries-elfeed)
			 (deactivate-mark)
			 (my-replace "\\(^\\*\\)" "\u200B\\1")
			 (whitespace-cleanup)
			 (buffer-string)))
	     (entries-final (with-temp-buffer
			       (org-mode)
			       (org-insert-heading)
			       (insert (concat "Entries " " -- " (format-time-string "%d/%m/%y")))
			       (save-restriction
				 (org-narrow-to-subtree)
				 (goto-char (point-max))
				 (insert entries)
				 (save-excursion
				   (goto-char (point-min))
				   (while (re-search-forward "\\(^¡>¡\\)" nil t)
				     (replace-match "" t nil)
				     (beginning-of-line)
				     (org-insert-heading))
				   (goto-char (point-min))
				   (forward-line)
				   (while (re-search-forward "^\\* " nil t)
				     (replace-match "** "))))
			       (buffer-substring (point-min) (point-max)))))
	  (org-paste-subtree (1+ level) entries-final)))))
#+end_src

The final function.

#+begin_src emacs-lisp
  (defun my-org/insert-entries-elfeed ()
    (interactive)
    (org-map-entries #'my-org/prepare-entries-elfeed
		     "+ELFEED={.+}" 'file nil))
#+end_src

* Test
  :PROPERTIES:
  :CREATED:   [2021-05-31 lun 11:28]
  :elfeed:   @6-months-ago +TeX New on CTAN
  :END:
